@@ -4,6 +4,8 @@ my $default_browser = get_default_browser;
 
 print 'Default browser is: ' . $default_browser . "\n" . 'Opening Google in default browser ...' . "\n";
 
-system '"' . $default_browser . '" "http://www.google.com"';
+sleep(5);
+
+system 'start "" "' . $default_browser . '" "http://www.google.com"';
 
 exit;
\ No newline at end of file
